==> gini-health-api-lib-1.2.2-sources.jar: net/gini/android/health/api/models/PaymentProvider.kt <==
package net.gini.android.health.api.models

import net.gini.android.health.api.response.PaymentProviderResponse

/**
 * A payment provider is a Gini partner which integrated the GiniPay for Banks SDK into their mobile apps.
 */
data class PaymentProvider(
    val id: String,
    val name: String,
    /**
     * Package name of the bank app that corresponds to this provider.
     */
    val packageName: String,
    /**
     * The minimal required app versions per platform.
     */
    val appVersion: String,
    /**
     * Colors to use when displaying the payment provider.
     */
    val colors: Colors,
    /**
     * The icon to use when displaying the payment provider.
     */
    val icon: ByteArray
) {

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as PaymentProvider

        if (id != other.id) return false
        if (name != other.name) return false
        if (packageName != other.packageName) return false
        if (appVersion != other.appVersion) return false
        if (colors != other.colors) return false
        if (!icon.contentEquals(other.icon)) return false

        return true
    }

    override fun hashCode(): Int {
        var result = id.hashCode()
        result = 31 * result + name.hashCode()
        result = 31 * result + packageName.hashCode()
        result = 31 * result + appVersion.hashCode()
        result = 31 * result + colors.hashCode()
        result = 31 * result + icon.contentHashCode()
        return result
    }

    /**
     * A payment provider's color scheme.
     */
    data class Colors(
        val backgroundColorRGBHex: String,
        val textColoRGBHex: String,
    )
}

internal fun PaymentProviderResponse.toPaymentProvider(icon: ByteArray) = PaymentProvider(
    id = id,
    name = name,
    packageName = packageNameAndroid,
    appVersion = minAppVersion.android,
    colors = PaymentProvider.Colors(
        backgroundColorRGBHex = colors.background,
        textColoRGBHex = colors.text,
    ),
    icon = icon
)

==> gini-health-api-lib-2.1.0-sources.jar: net/gini/android/health/api/models/PaymentProvider.kt <==
package net.gini.android.health.api.models

import net.gini.android.health.api.response.PaymentProviderResponse

/**
 * A payment provider is a Gini partner which integrated Gini Pay Connect (via Gini Bank SDK) into their mobile apps.
 */
data class PaymentProvider(
    val id: String,
    val name: String,
    /**
     * Package name of the bank app that corresponds to this provider.
     */
    val packageName: String,
    /**
     * The minimal required app versions per platform.
     */
    val appVersion: String,
    /**
     * Colors to use when displaying the payment provider.
     */
    val colors: Colors,
    /**
     * The icon to use when displaying the payment provider.
     */
    val icon: ByteArray
) {

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as PaymentProvider

        if (id != other.id) return false
        if (name != other.name) return false
        if (packageName != other.packageName) return false
        if (appVersion != other.appVersion) return false
        if (colors != other.colors) return false
        if (!icon.contentEquals(other.icon)) return false

        return true
    }

    override fun hashCode(): Int {
        var result = id.hashCode()
        result = 31 * result + name.hashCode()
        result = 31 * result + packageName.hashCode()
        result = 31 * result + appVersion.hashCode()
        result = 31 * result + colors.hashCode()
        result = 31 * result + icon.contentHashCode()
        return result
    }

    /**
     * A payment provider's color scheme.
     */
    data class Colors(
        val backgroundColorRGBHex: String,
        val textColoRGBHex: String,
    )
}

internal fun PaymentProviderResponse.toPaymentProvider(icon: ByteArray) = PaymentProvider(
    id = id,
    name = name,
    packageName = packageNameAndroid,
    appVersion = minAppVersion.android,
    colors = PaymentProvider.Colors(
        backgroundColorRGBHex = colors.background,
        textColoRGBHex = colors.text,
    ),
    icon = icon
)
